@@ -26,13 +26,13 @@ use std::str::FromStr;
 use indexmap::{IndexMap, IndexSet};
 
 /// VCF header info records.
-pub type Infos = IndexMap<crate::record::info::field::Key, Info>;
+pub type Infos = IndexMap<info::Key, Info>;
 
 /// VCF header filter records.
 pub type Filters = IndexMap<String, Filter>;
 
 /// VCF header format records.
-pub type Formats = IndexMap<crate::record::genotypes::genotype::field::Key, Format>;
+pub type Formats = IndexMap<format::Key, Format>;
 
 /// VCF header alternative allele records.
 pub type AlternativeAlleles =
@@ -128,7 +128,7 @@ impl Header {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{self as vcf, header::Info, record::info::field::Key};
+    /// use noodles_vcf::{self as vcf, header::{info::Key, Info}};
     ///
     /// let header = vcf::Header::builder()
     ///     .add_info(Info::from(Key::SamplesWithDataCount))
@@ -147,7 +147,7 @@ impl Header {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{self as vcf, header::Info, record::info::field::Key};
+    /// use noodles_vcf::{self as vcf, header::{info::Key, Info}};
     ///
     /// let mut header = vcf::Header::default();
     ///
@@ -206,7 +206,7 @@ impl Header {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{self as vcf, header::Format, record::genotypes::genotype::field::Key};
+    /// use noodles_vcf::{self as vcf, header::{format::Key, Format}};
     ///
     /// let header = vcf::Header::builder()
     ///     .add_format(Format::from(Key::Genotype))
@@ -225,7 +225,7 @@ impl Header {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{self as vcf, header::Format, record::genotypes::genotype::field::Key};
+    /// use noodles_vcf::{self as vcf, header::{format::Key, Format}};
     ///
     /// let mut header = vcf::Header::default();
     ///
