@@ -9,14 +9,18 @@ use std::{error, fmt, num};
 
 use indexmap::IndexMap;
 
-use crate::record::genotypes::genotype;
-
 use super::{number, record, FileFormat, Number, Record};
 
+const ID: &str = "ID";
+const NUMBER: &str = "Number";
+const TYPE: &str = "Type";
+const DESCRIPTION: &str = "Description";
+const IDX: &str = "IDX";
+
 /// A VCF header genotype format record (`FORMAT`).
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub struct Format {
-    id: genotype::field::Key,
+    id: Key,
     number: Number,
     ty: Type,
     description: String,
@@ -30,13 +34,14 @@ impl Format {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{
-    ///     header::{format::Type, record::{Key, Value}, FileFormat, Format, Number, Record},
-    ///     record::genotypes::genotype,
+    /// use noodles_vcf::header::{
+    ///     format::{Key as FormatKey, Type},
+    ///     record::{Key as RecordKey, Value},
+    ///     FileFormat, Format, Number, Record,
     /// };
     ///
     /// let record = Record::new(
-    ///     Key::Format,
+    ///     RecordKey::Format,
     ///     Value::Struct(vec![
     ///         (String::from("ID"), String::from("GT")),
     ///         (String::from("Number"), String::from("1")),
@@ -48,7 +53,7 @@ impl Format {
     /// assert_eq!(
     ///     Format::try_from_record_file_format(record, FileFormat::new(4, 3)),
     ///     Ok(Format::new(
-    ///         genotype::field::Key::Genotype,
+    ///         FormatKey::Genotype,
     ///         Number::Count(1),
     ///         Type::String,
     ///         String::from("Genotype"),
@@ -72,10 +77,7 @@ impl Format {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{
-    ///     header::{format::Type, Format, Number},
-    ///     record::genotypes::genotype::field::Key,
-    /// };
+    /// use noodles_vcf::header::{format::{Key, Type}, Format, Number};
     ///
     /// let format = Format::new(
     ///     Key::Genotype,
@@ -84,7 +86,7 @@ impl Format {
     ///     String::from("Genotype"),
     /// );
     /// ```
-    pub fn new(id: genotype::field::Key, number: Number, ty: Type, description: String) -> Self {
+    pub fn new(id: Key, number: Number, ty: Type, description: String) -> Self {
         Self {
             id,
             number,
@@ -100,11 +102,11 @@ impl Format {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::Format, record::genotypes::genotype::field::Key};
+    /// use noodles_vcf::header::{format::Key, Format};
     /// let format = Format::from(Key::Genotype);
     /// assert_eq!(format.id(), &Key::Genotype);
     /// ```
-    pub fn id(&self) -> &genotype::field::Key {
+    pub fn id(&self) -> &Key {
         &self.id
     }
 
@@ -113,7 +115,7 @@ impl Format {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::{Format, Number}, record::genotypes::genotype::field::Key};
+    /// use noodles_vcf::header::{format::Key, Format, Number};
     /// let format = Format::from(Key::Genotype);
     /// assert_eq!(format.number(), Number::Count(1));
     /// ```
@@ -126,7 +128,7 @@ impl Format {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::{format::Type, Format}, record::genotypes::genotype::field::Key};
+    /// use noodles_vcf::header::{format::{Key, Type}, Format};
     /// let format = Format::from(Key::Genotype);
     /// assert_eq!(format.ty(), Type::String);
     /// ```
@@ -139,7 +141,7 @@ impl Format {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::Format, record::genotypes::genotype::field::Key};
+    /// use noodles_vcf::header::{format::Key, Format};
     /// let format = Format::from(Key::Genotype);
     /// assert_eq!(format.description(), "Genotype");
     /// ```
@@ -154,7 +156,7 @@ impl Format {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::Format, record::genotypes::genotype::field::Key};
+    /// use noodles_vcf::header::{format::Key, Format};
     /// let format = Format::from(Key::Genotype);
     /// assert!(format.idx().is_none());
     /// ```
@@ -169,7 +171,7 @@ impl Format {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::Format, record::genotypes::genotype::field::Key};
+    /// use noodles_vcf::header::{format::Key, Format};
     /// let format = Format::from(Key::Genotype);
     /// assert!(format.fields().is_empty());
     /// ```
@@ -178,11 +180,11 @@ impl Format {
     }
 }
 
-impl From<genotype::field::Key> for Format {
-    fn from(key: genotype::field::Key) -> Self {
-        let number = key.number();
-        let ty = key.ty();
-        let description = key.description().to_string();
+impl From<Key> for Format {
+    fn from(key: Key) -> Self {
+        let number = key::number(&key).unwrap_or(Number::Count(1));
+        let ty = key::ty(&key).unwrap_or(Type::String);
+        let description = key::description(&key).map(|s| s.into()).unwrap_or_default();
         Self::new(key, number, ty, description)
     }
 }
@@ -193,11 +195,11 @@ impl fmt::Display for Format {
         f.write_str(record::Key::Format.as_ref())?;
         f.write_str("=<")?;
 
-        write!(f, "{}={}", Key::Id, self.id)?;
-        write!(f, ",{}={}", Key::Number, self.number)?;
-        write!(f, ",{}={}", Key::Type, self.ty)?;
+        write!(f, "{}={}", ID, self.id)?;
+        write!(f, ",{}={}", NUMBER, self.number)?;
+        write!(f, ",{}={}", TYPE, self.ty)?;
 
-        write!(f, ",{}=", Key::Description)?;
+        write!(f, ",{}=", DESCRIPTION)?;
         super::fmt::write_escaped_string(f, self.description())?;
 
         for (key, value) in &self.fields {
@@ -206,7 +208,7 @@ impl fmt::Display for Format {
         }
 
         if let Some(idx) = self.idx() {
-            write!(f, ",{}={}", Key::Idx, idx)?;
+            write!(f, ",{}={}", IDX, idx)?;
         }
 
         f.write_str(">")?;
@@ -222,9 +224,9 @@ pub enum TryFromRecordError {
     /// The record is invalid.
     InvalidRecord,
     /// A required field is missing.
-    MissingField(Key),
+    MissingField(&'static str),
     /// The ID is invalid.
-    InvalidId(genotype::field::key::ParseError),
+    InvalidId(key::ParseError),
     /// The number is invalid.
     InvalidNumber(number::ParseError),
     /// The type is invalid.
@@ -247,7 +249,7 @@ impl fmt::Display for TryFromRecordError {
             Self::InvalidId(e) => write!(f, "invalid ID: {}", e),
             Self::InvalidNumber(e) => write!(f, "invalid number: {}", e),
             Self::InvalidType(e) => write!(f, "invalid type: {}", e),
-            Self::InvalidIdx(e) => write!(f, "invalid index (`{}`): {}", Key::Idx, e),
+            Self::InvalidIdx(e) => write!(f, "invalid index (`{}`): {}", IDX, e),
             Self::NumberMismatch(actual, expected) => {
                 write!(f, "number mismatch: expected {}, got {}", expected, actual)
             }
@@ -274,52 +276,54 @@ fn parse_struct(
 
     let id = it
         .next()
-        .ok_or(TryFromRecordError::MissingField(Key::Id))
-        .and_then(|(k, v)| match k.parse() {
-            Ok(Key::Id) => v.parse().map_err(TryFromRecordError::InvalidId),
-            _ => Err(TryFromRecordError::MissingField(Key::Id)),
+        .ok_or(TryFromRecordError::MissingField(ID))
+        .and_then(|(k, v)| match k.as_ref() {
+            ID => v.parse().map_err(TryFromRecordError::InvalidId),
+            _ => Err(TryFromRecordError::MissingField(ID)),
         })?;
 
     let number = it
         .next()
-        .ok_or(TryFromRecordError::MissingField(Key::Number))
-        .and_then(|(k, v)| match k.parse() {
-            Ok(Key::Number) => v.parse().map_err(TryFromRecordError::InvalidNumber),
-            _ => Err(TryFromRecordError::MissingField(Key::Id)),
+        .ok_or(TryFromRecordError::MissingField(NUMBER))
+        .and_then(|(k, v)| match k.as_ref() {
+            NUMBER => v.parse().map_err(TryFromRecordError::InvalidNumber),
+            _ => Err(TryFromRecordError::MissingField(NUMBER)),
         })?;
 
     let ty = it
         .next()
-        .ok_or(TryFromRecordError::MissingField(Key::Type))
-        .and_then(|(k, v)| match k.parse() {
-            Ok(Key::Type) => v.parse().map_err(TryFromRecordError::InvalidType),
-            _ => Err(TryFromRecordError::MissingField(Key::Type)),
+        .ok_or(TryFromRecordError::MissingField(TYPE))
+        .and_then(|(k, v)| match k.as_ref() {
+            TYPE => v.parse().map_err(TryFromRecordError::InvalidType),
+            _ => Err(TryFromRecordError::MissingField(TYPE)),
         })?;
 
-    if file_format >= FileFormat::new(4, 3) && !matches!(id, genotype::field::Key::Other(..)) {
-        if id.number() != number {
-            return Err(TryFromRecordError::NumberMismatch(number, id.number()));
-        }
+    if file_format >= FileFormat::new(4, 3) && !matches!(id, Key::Other(..)) {
+        if let (Some(expected_number), Some(expected_type)) = (key::number(&id), key::ty(&id)) {
+            if number != expected_number {
+                return Err(TryFromRecordError::NumberMismatch(number, expected_number));
+            }
 
-        if id.ty() != ty {
-            return Err(TryFromRecordError::TypeMismatch(ty, id.ty()));
+            if ty != expected_type {
+                return Err(TryFromRecordError::TypeMismatch(ty, expected_type));
+            }
         }
     }
 
     let description = it
         .next()
-        .ok_or(TryFromRecordError::MissingField(Key::Description))
-        .and_then(|(k, v)| match k.parse() {
-            Ok(Key::Description) => Ok(v),
-            _ => Err(TryFromRecordError::MissingField(Key::Description)),
+        .ok_or(TryFromRecordError::MissingField(DESCRIPTION))
+        .and_then(|(k, v)| match k.as_ref() {
+            DESCRIPTION => Ok(v),
+            _ => Err(TryFromRecordError::MissingField(DESCRIPTION)),
         })?;
 
     let mut idx = None;
     let mut fields = IndexMap::new();
 
     for (key, value) in it {
-        match key.parse() {
-            Ok(Key::Idx) => {
+        match key.as_ref() {
+            IDX => {
                 idx = value
                     .parse()
                     .map(Some)
@@ -359,10 +363,10 @@ mod tests {
 
     #[test]
     fn test_from_genotype_field_key_for_format() {
-        let actual = Format::from(genotype::field::Key::Genotype);
+        let actual = Format::from(Key::Genotype);
 
         let expected = Format::new(
-            genotype::field::Key::Genotype,
+            Key::Genotype,
             Number::Count(1),
             Type::String,
             String::from("Genotype"),
@@ -397,7 +401,7 @@ mod tests {
         assert_eq!(
             Format::try_from_record_file_format(record, FileFormat::new(4, 2)),
             Ok(Format::new(
-                genotype::field::Key::Genotype,
+                Key::Genotype,
                 Number::Unknown,
                 Type::String,
                 String::from("Genotype"),
@@ -412,7 +416,7 @@ mod tests {
         assert_eq!(
             Format::try_from(record),
             Ok(Format::new(
-                genotype::field::Key::Genotype,
+                Key::Genotype,
                 Number::Count(1),
                 Type::String,
                 String::from("Genotype"),
@@ -437,7 +441,7 @@ mod tests {
         assert_eq!(
             Format::try_from(record),
             Ok(Format {
-                id: genotype::field::Key::Genotype,
+                id: Key::Genotype,
                 number: Number::Count(1),
                 ty: Type::String,
                 description: String::from("Genotype"),
