@@ -9,14 +9,18 @@ use std::{error, fmt, num};
 
 use indexmap::IndexMap;
 
-use crate::record::info;
-
 use super::{number, record, FileFormat, Number, Record};
 
+const ID: &str = "ID";
+const NUMBER: &str = "Number";
+const TYPE: &str = "Type";
+const DESCRIPTION: &str = "Description";
+const IDX: &str = "IDX";
+
 /// A VCF header information record (`INFO`).
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub struct Info {
-    id: info::field::Key,
+    id: Key,
     number: Number,
     ty: Type,
     description: String,
@@ -30,13 +34,14 @@ impl Info {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{
-    ///     header::{info::Type, record::{Key, Value}, FileFormat, Info, Number, Record},
-    ///     record::info,
+    /// use noodles_vcf::header::{
+    ///     info::{Key as InfoKey, Type},
+    ///     record::{Key as RecordKey, Value},
+    ///     FileFormat, Info, Number, Record,
     /// };
     ///
     /// let record = Record::new(
-    ///     Key::Info,
+    ///     RecordKey::Info,
     ///     Value::Struct(vec![
     ///         (String::from("ID"), String::from("NS")),
     ///         (String::from("Number"), String::from("1")),
@@ -51,7 +56,7 @@ impl Info {
     /// assert_eq!(
     ///     Info::try_from_record_file_format(record, FileFormat::new(4, 3)),
     ///     Ok(Info::new(
-    ///         info::field::Key::SamplesWithDataCount,
+    ///         InfoKey::SamplesWithDataCount,
     ///         Number::Count(1),
     ///         Type::Integer,
     ///         String::from("Number of samples with data"),
@@ -73,10 +78,7 @@ impl Info {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{
-    ///     header::{info::Type, Info, Number},
-    ///     record::info::field::Key,
-    /// };
+    /// use noodles_vcf::header::{info::{Key, Type}, Info, Number};
     ///
     /// let info = Info::new(
     ///     Key::SamplesWithDataCount,
@@ -85,7 +87,7 @@ impl Info {
     ///     String::from("Number of samples with data"),
     /// );
     /// ```
-    pub fn new(id: info::field::Key, number: Number, ty: Type, description: String) -> Self {
+    pub fn new(id: Key, number: Number, ty: Type, description: String) -> Self {
         Self {
             id,
             number,
@@ -101,11 +103,11 @@ impl Info {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::Info, record::info::field::Key};
+    /// use noodles_vcf::header::{info::Key, Info};
     /// let info = Info::from(Key::SamplesWithDataCount);
     /// assert_eq!(info.id(), &Key::SamplesWithDataCount);
     /// ```
-    pub fn id(&self) -> &info::field::Key {
+    pub fn id(&self) -> &Key {
         &self.id
     }
 
@@ -114,7 +116,7 @@ impl Info {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::{Info, Number}, record::info::field::Key};
+    /// use noodles_vcf::header::{info::Key, Info, Number};
     /// let info = Info::from(Key::SamplesWithDataCount);
     /// assert_eq!(info.number(), Number::Count(1));
     /// ```
@@ -127,7 +129,7 @@ impl Info {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::{info::Type, Info}, record::info::field::Key};
+    /// use noodles_vcf::header::{info::{Key, Type}, Info};
     /// let info = Info::from(Key::SamplesWithDataCount);
     /// assert_eq!(info.ty(), Type::Integer);
     /// ```
@@ -140,7 +142,7 @@ impl Info {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::Info, record::info::field::Key};
+    /// use noodles_vcf::header::{info::Key, Info};
     /// let info = Info::from(Key::SamplesWithDataCount);
     /// assert_eq!(info.description(), "Number of samples with data");
     /// ```
@@ -155,7 +157,7 @@ impl Info {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::Info, record::info::field::Key};
+    /// use noodles_vcf::header::{info::Key, Info};
     /// let info = Info::from(Key::SamplesWithDataCount);
     /// assert!(info.idx().is_none());
     /// ```
@@ -170,7 +172,7 @@ impl Info {
     /// # Examples
     ///
     /// ```
-    /// use noodles_vcf::{header::Info, record::info::field::Key};
+    /// use noodles_vcf::header::{info::Key, Info};
     /// let info = Info::from(Key::SamplesWithDataCount);
     /// assert!(info.fields().is_empty());
     /// ```
@@ -179,11 +181,11 @@ impl Info {
     }
 }
 
-impl From<info::field::Key> for Info {
-    fn from(key: info::field::Key) -> Self {
-        let number = key.number();
-        let ty = key.ty();
-        let description = key.description().to_string();
+impl From<Key> for Info {
+    fn from(key: Key) -> Self {
+        let number = key::number(&key).unwrap_or(Number::Count(1));
+        let ty = key::ty(&key).unwrap_or(Type::String);
+        let description = key::description(&key).map(|s| s.into()).unwrap_or_default();
         Self::new(key, number, ty, description)
     }
 }
@@ -194,11 +196,11 @@ impl fmt::Display for Info {
         f.write_str(record::Key::Info.as_ref())?;
         f.write_str("=<")?;
 
-        write!(f, "{}={}", Key::Id, self.id)?;
-        write!(f, ",{}={}", Key::Number, self.number)?;
-        write!(f, ",{}={}", Key::Type, self.ty)?;
+        write!(f, "{}={}", ID, self.id)?;
+        write!(f, ",{}={}", NUMBER, self.number)?;
+        write!(f, ",{}={}", TYPE, self.ty)?;
 
-        write!(f, ",{}=", Key::Description)?;
+        write!(f, ",{}=", DESCRIPTION)?;
         super::fmt::write_escaped_string(f, self.description())?;
 
         for (key, value) in &self.fields {
@@ -207,7 +209,7 @@ impl fmt::Display for Info {
         }
 
         if let Some(idx) = self.idx() {
-            write!(f, ",{}={}", Key::Idx, idx)?;
+            write!(f, ",{}={}", IDX, idx)?;
         }
 
         f.write_str(">")?;
@@ -222,9 +224,9 @@ pub enum TryFromRecordError {
     /// The record is invalid.
     InvalidRecord,
     /// A required field is missing.
-    MissingField(Key),
+    MissingField(&'static str),
     /// The ID is invalid.
-    InvalidId(info::field::key::ParseError),
+    InvalidId(key::ParseError),
     /// The number is invalid.
     InvalidNumber(number::ParseError),
     /// The type is invalid.
@@ -247,7 +249,7 @@ impl fmt::Display for TryFromRecordError {
             Self::InvalidId(e) => write!(f, "invalid ID: {}", e),
             Self::InvalidNumber(e) => write!(f, "invalid number: {}", e),
             Self::InvalidType(e) => write!(f, "invalid type: {}", e),
-            Self::InvalidIdx(e) => write!(f, "invalid index (`{}`): {}", Key::Idx, e),
+            Self::InvalidIdx(e) => write!(f, "invalid index (`{}`): {}", IDX, e),
             Self::NumberMismatch(actual, expected) => {
                 write!(f, "number mismatch: expected {}, got {}", expected, actual)
             }
@@ -274,52 +276,54 @@ fn parse_struct(
 
     let id = it
         .next()
-        .ok_or(TryFromRecordError::MissingField(Key::Id))
-        .and_then(|(k, v)| match k.parse() {
-            Ok(Key::Id) => v.parse().map_err(TryFromRecordError::InvalidId),
-            _ => Err(TryFromRecordError::MissingField(Key::Id)),
+        .ok_or(TryFromRecordError::MissingField(ID))
+        .and_then(|(k, v)| match k.as_ref() {
+            ID => v.parse().map_err(TryFromRecordError::InvalidId),
+            _ => Err(TryFromRecordError::MissingField(ID)),
         })?;
 
     let number = it
         .next()
-        .ok_or(TryFromRecordError::MissingField(Key::Number))
-        .and_then(|(k, v)| match k.parse() {
-            Ok(Key::Number) => v.parse().map_err(TryFromRecordError::InvalidNumber),
-            _ => Err(TryFromRecordError::MissingField(Key::Id)),
+        .ok_or(TryFromRecordError::MissingField(NUMBER))
+        .and_then(|(k, v)| match k.as_ref() {
+            NUMBER => v.parse().map_err(TryFromRecordError::InvalidNumber),
+            _ => Err(TryFromRecordError::MissingField(NUMBER)),
         })?;
 
     let ty = it
         .next()
-        .ok_or(TryFromRecordError::MissingField(Key::Type))
-        .and_then(|(k, v)| match k.parse() {
-            Ok(Key::Type) => v.parse().map_err(TryFromRecordError::InvalidType),
-            _ => Err(TryFromRecordError::MissingField(Key::Type)),
+        .ok_or(TryFromRecordError::MissingField(TYPE))
+        .and_then(|(k, v)| match k.as_ref() {
+            TYPE => v.parse().map_err(TryFromRecordError::InvalidType),
+            _ => Err(TryFromRecordError::MissingField(TYPE)),
         })?;
 
-    if file_format >= FileFormat::new(4, 3) && !matches!(id, info::field::Key::Other(..)) {
-        if id.number() != number {
-            return Err(TryFromRecordError::NumberMismatch(number, id.number()));
-        }
+    if file_format >= FileFormat::new(4, 3) && !matches!(id, Key::Other(..)) {
+        if let (Some(expected_number), Some(expected_type)) = (key::number(&id), key::ty(&id)) {
+            if number != expected_number {
+                return Err(TryFromRecordError::NumberMismatch(number, expected_number));
+            }
 
-        if id.ty() != ty {
-            return Err(TryFromRecordError::TypeMismatch(ty, id.ty()));
+            if ty != expected_type {
+                return Err(TryFromRecordError::TypeMismatch(ty, expected_type));
+            }
         }
     }
 
     let description = it
         .next()
-        .ok_or(TryFromRecordError::MissingField(Key::Description))
-        .and_then(|(k, v)| match k.parse() {
-            Ok(Key::Description) => Ok(v),
-            _ => Err(TryFromRecordError::MissingField(Key::Description)),
+        .ok_or(TryFromRecordError::MissingField(DESCRIPTION))
+        .and_then(|(k, v)| match k.as_ref() {
+            DESCRIPTION => Ok(v),
+            _ => Err(TryFromRecordError::MissingField(DESCRIPTION)),
         })?;
 
     let mut idx = None;
     let mut fields = IndexMap::new();
 
     for (key, value) in it {
-        match key.parse() {
-            Ok(Key::Idx) => {
+        match key.as_ref() {
+            IDX => {
                 idx = value
                     .parse()
                     .map(Some)
@@ -362,10 +366,10 @@ mod tests {
 
     #[test]
     fn test_from_info_field_key_for_info() {
-        let actual = Info::from(info::field::Key::SamplesWithDataCount);
+        let actual = Info::from(Key::SamplesWithDataCount);
 
         let expected = Info::new(
-            info::field::Key::SamplesWithDataCount,
+            Key::SamplesWithDataCount,
             Number::Count(1),
             Type::Integer,
             String::from("Number of samples with data"),
@@ -404,7 +408,7 @@ mod tests {
         assert_eq!(
             Info::try_from_record_file_format(record, FileFormat::new(4, 2)),
             Ok(Info::new(
-                info::field::Key::SamplesWithDataCount,
+                Key::SamplesWithDataCount,
                 Number::Unknown,
                 Type::Integer,
                 String::from("Number of samples with data"),
@@ -419,7 +423,7 @@ mod tests {
         assert_eq!(
             Info::try_from(record),
             Ok(Info::new(
-                info::field::Key::SamplesWithDataCount,
+                Key::SamplesWithDataCount,
                 Number::Count(1),
                 Type::Integer,
                 String::from("Number of samples with data"),
@@ -448,7 +452,7 @@ mod tests {
         assert_eq!(
             Info::try_from(record),
             Ok(Info {
-                id: info::field::Key::SamplesWithDataCount,
+                id: Key::SamplesWithDataCount,
                 number: Number::Count(1),
                 ty: Type::Integer,
                 description: String::from("Number of samples with data"),
