@@ -5,11 +5,14 @@ mod records;
 
 pub use self::{query::Query, records::Records};
 
-use std::io::{self, BufRead, Read, Seek};
+use std::{
+    io::{self, BufRead, Read, Seek},
+    ops::Bound,
+};
 
 use memchr::memchr;
 use noodles_bgzf as bgzf;
-use noodles_core::{region::Interval, Region};
+use noodles_core::{Position, Region};
 use noodles_csi::BinningIndex;
 use noodles_tabix as tabix;
 
@@ -279,7 +282,7 @@ where
     /// let header = reader.read_header()?.parse()?;
     ///
     /// let index = tabix::read("sample.vcf.gz.tbi")?;
-    /// let region = Region::mapped("sq0", 8..=13);
+    /// let region = "sq0:8-13".parse()?;
     /// let query = reader.query(&header, &index, &region)?;
     ///
     /// for result in query {
@@ -297,7 +300,7 @@ where
         let (reference_sequence_id, reference_sequence_name, interval) =
             resolve_region(index, region)?;
 
-        let chunks = index.query(reference_sequence_id, interval)?;
+        let chunks = index.query(reference_sequence_id, region.interval())?;
 
         Ok(Query::new(
             self,
@@ -369,31 +372,38 @@ where
     }
 }
 
+#[allow(clippy::type_complexity)]
 pub(crate) fn resolve_region(
     index: &tabix::Index,
     region: &Region,
-) -> io::Result<(usize, String, Interval)> {
-    if let Some(r) = region.as_mapped() {
-        let i = index
-            .reference_sequence_names()
-            .get_index_of(r.name())
-            .ok_or_else(|| {
-                io::Error::new(
-                    io::ErrorKind::InvalidInput,
-                    format!(
-                        "region reference sequence does not exist in reference sequences: {:?}",
-                        region
-                    ),
-                )
-            })?;
-
-        Ok((i, r.name().into(), r.interval()))
-    } else {
-        Err(io::Error::new(
-            io::ErrorKind::InvalidData,
-            "region is not mapped",
-        ))
+) -> io::Result<(usize, String, (Bound<i32>, Bound<i32>))> {
+    fn cast_bound_position_to_bound_i32(bound: Bound<Position>) -> Bound<i32> {
+        match bound {
+            Bound::Included(position) => Bound::Included(usize::from(position) as i32),
+            Bound::Excluded(position) => Bound::Excluded(usize::from(position) as i32),
+            Bound::Unbounded => Bound::Unbounded,
+        }
     }
+
+    let i = index
+        .reference_sequence_names()
+        .get_index_of(region.name())
+        .ok_or_else(|| {
+            io::Error::new(
+                io::ErrorKind::InvalidInput,
+                format!(
+                    "region reference sequence does not exist in reference sequences: {:?}",
+                    region
+                ),
+            )
+        })?;
+
+    let interval = (
+        cast_bound_position_to_bound_i32(region.start()),
+        cast_bound_position_to_bound_i32(region.end()),
+    );
+
+    Ok((i, region.name().into(), interval))
 }
 
 #[cfg(test)]
