@@ -433,7 +433,8 @@ impl Record {
     /// ```
     /// use noodles_vcf::{
     ///     self as vcf,
-    ///     record::{info::{field::{Key, Value}, Field}, Info, Position},
+    ///     header::info::Key,
+    ///     record::{info::{field::Value, Field}, Info, Position},
     /// };
     ///
     /// let record = vcf::Record::builder()
@@ -463,7 +464,8 @@ impl Record {
     /// ```
     /// use noodles_vcf::{
     ///     self as vcf,
-    ///     record::{info::{field::{Key, Value}, Field}, Info, Position},
+    ///     header::info::Key,
+    ///     record::{info::{field::Value, Field}, Info, Position},
     /// };
     ///
     /// let mut record = vcf::Record::builder()
@@ -497,11 +499,17 @@ impl Record {
     /// ```
     /// use noodles_vcf::{
     ///     self as vcf,
-    ///     record::{genotypes::{genotype::field::Key, Genotype, Keys}, Genotypes, Position},
+    ///     header::{format::Key, Format},
+    ///     record::{genotypes::{Genotype, Keys}, Genotypes, Position},
     /// };
     ///
+    /// let header = vcf::Header::builder()
+    ///     .add_format(Format::from(Key::Genotype))
+    ///     .add_format(Format::from(Key::ConditionalGenotypeQuality))
+    ///     .build();
+    ///
     /// let keys = "GT:GQ".parse()?;
-    /// let genotypes = vec![Genotype::from_str_keys("0|0:13", &keys)?];
+    /// let genotypes = vec![Genotype::parse("0|0:13", header.formats(), &keys)?];
     ///
     /// let record = vcf::Record::builder()
     ///     .set_chromosome("sq0".parse()?)
@@ -527,8 +535,9 @@ impl Record {
     /// ```
     /// use noodles_vcf::{
     ///     self as vcf,
+    ///     header::format::Key,
     ///     record::{
-    ///         genotypes::{genotype::{field::{Key, Value}, Field}, Genotype, Genotypes},
+    ///         genotypes::{genotype::{field::Value, Field}, Genotype, Genotypes},
     ///         Position,
     ///     },
     /// };
@@ -564,8 +573,9 @@ impl Record {
     /// ```
     /// use noodles_vcf::{
     ///     self as vcf,
+    ///     header::format::Key,
     ///     record::{
-    ///         genotypes::{genotype::{field::{Key, Value}, Field}, Genotype, Genotypes},
+    ///         genotypes::{genotype::{field::Value, Field}, Genotype, Genotypes},
     ///         Position,
     ///     },
     /// };
@@ -670,7 +680,8 @@ impl Record {
     /// # Ok::<(), Box<dyn std::error::Error>>(())
     /// ```
     pub fn end(&self) -> Result<Position, EndError> {
-        use info::field::{Key, Value};
+        use self::info::field::Value;
+        use super::header::info::Key;
 
         let end = if let Some(value) = self.info().get(&Key::EndPosition).and_then(|f| f.value()) {
             match value {
@@ -739,12 +750,14 @@ mod tests {
 
     #[test]
     fn test_end() -> Result<(), Box<dyn std::error::Error>> {
+        use crate::header::info::Key as InfoKey;
+
         let record = Record::builder()
             .set_chromosome("sq0".parse()?)
             .set_position(Position::try_from(1)?)
             .set_reference_bases("A".parse()?)
             .set_info(Info::try_from(vec![info::Field::new(
-                info::field::Key::EndPosition,
+                InfoKey::EndPosition,
                 None,
             )])?)
             .build()?;
@@ -756,7 +769,7 @@ mod tests {
             .set_position(Position::try_from(1)?)
             .set_reference_bases("A".parse()?)
             .set_info(Info::try_from(vec![info::Field::new(
-                info::field::Key::EndPosition,
+                InfoKey::EndPosition,
                 Some(info::field::Value::Flag),
             )])?)
             .build()?;
@@ -792,10 +805,19 @@ mod tests {
 
     #[test]
     fn test_fmt_with_format() -> Result<(), Box<dyn std::error::Error>> {
-        use genotypes::Genotype;
+        use super::genotypes::Genotype;
+        use crate::{
+            header::{format::Key, Format},
+            Header,
+        };
+
+        let header = Header::builder()
+            .add_format(Format::from(Key::Genotype))
+            .add_format(Format::from(Key::ConditionalGenotypeQuality))
+            .build();
 
         let keys: genotypes::Keys = "GT:GQ".parse()?;
-        let genotypes = vec![Genotype::from_str_keys("0|0:13", &keys)?];
+        let genotypes = vec![Genotype::parse("0|0:13", header.formats(), &keys)?];
 
         let record = Record::builder()
             .set_chromosome("sq0".parse()?)
